summaryrefslogtreecommitdiff
path: root/nuttx/include
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2008-12-02 19:08:19 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2008-12-02 19:08:19 +0000
commit124c331605b174afc08f7ef498209952b4a1dbc5 (patch)
tree13ad75d2599d5e125e19949c422327816df1decb /nuttx/include
parent763c04c953eb1111d1020653a8edb9688d3211c9 (diff)
downloadpx4-nuttx-124c331605b174afc08f7ef498209952b4a1dbc5.tar.gz
px4-nuttx-124c331605b174afc08f7ef498209952b4a1dbc5.tar.bz2
px4-nuttx-124c331605b174afc08f7ef498209952b4a1dbc5.zip
More NXTK files
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@1391 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/include')
-rw-r--r--nuttx/include/nuttx/nx.h2
-rw-r--r--nuttx/include/nuttx/nxtk.h110
2 files changed, 109 insertions, 3 deletions
diff --git a/nuttx/include/nuttx/nx.h b/nuttx/include/nuttx/nx.h
index a5614caff..a3ffe1b32 100644
--- a/nuttx/include/nuttx/nx.h
+++ b/nuttx/include/nuttx/nx.h
@@ -598,7 +598,7 @@ EXTERN int nx_fill(NXWINDOW hwnd, FAR const struct nxgl_rect_s *rect,
*
* Input Parameters:
* hwnd - The window handle
- * clip - Clipping region (may be null)
+ * clip - Clipping rectangle relative to window (may be null)
* trap - The trapezoidal region to be filled
* color - The color to use in the fill
*
diff --git a/nuttx/include/nuttx/nxtk.h b/nuttx/include/nuttx/nxtk.h
index 4081450e0..117a4cc71 100644
--- a/nuttx/include/nuttx/nxtk.h
+++ b/nuttx/include/nuttx/nxtk.h
@@ -172,6 +172,24 @@ EXTERN int nxtk_setposition(NXTKWINDOW hfwnd, FAR struct nxgl_point_s *pos);
EXTERN int nxtk_setsize(NXTKWINDOW hfwnd, FAR struct nxgl_rect_s *size);
/****************************************************************************
+ * Name: nxtk_raise
+ *
+ * Description:
+ * Bring the window containing the specified client sub-window to the top
+ * of the display.
+ *
+ * Input parameters:
+ * hfwnd - the window to be raised. This must have been previously created
+ * by nxtk_openwindow().
+ *
+ * Returned value:
+ * OK on success; ERROR on failure with errno set appropriately
+ *
+ ****************************************************************************/
+
+EXTERN int nxtk_raise(NXTKWINDOW hfwnd);
+
+/****************************************************************************
* Name: nxtk_fillwindow
*
* Description:
@@ -191,13 +209,82 @@ EXTERN int nxtk_fillwindow(NXTKWINDOW hfwnd, FAR const struct nxgl_rect_s *rect,
nxgl_mxpixel_t color[CONFIG_NX_NPLANES]);
/****************************************************************************
+ * Name: nxtk_filltrapwindow
+ *
+ * Description:
+ * Fill the specified rectangle in the client window with the specified color
+ *
+ * Input Parameters:
+ * hfwnd - The window handle returned by nxtk_openwindow
+ * trap - The trapezoidal region to be filled
+ * color - The color to use in the fill
+ *
+ * Return:
+ * OK on success; ERROR on failure with errno set appropriately
+ *
+ ****************************************************************************/
+
+EXTERN int nxtk_filltrapwindow(NXTKWINDOW hfwnd,
+ FAR const struct nxgl_trapezoid_s *trap,
+ nxgl_mxpixel_t color[CONFIG_NX_NPLANES]);
+
+/****************************************************************************
+ * Name: nxtk_movewindow
+ *
+ * Description:
+ * Move a rectangular region within the client sub-window of a framed window
+ *
+ * Input Parameters:
+ * hfwnd - The client sub-window within which the move is to be done.
+ * This must have been previously created by nxtk_openwindow().
+ * rect - Describes the rectangular region relative to the client
+ * sub-window to move
+ * offset - The offset to move the region
+ *
+ * Return:
+ * OK on success; ERROR on failure with errno set appropriately
+ *
+ ****************************************************************************/
+
+EXTERN int nxtk_movewindow(NXTKWINDOW hfwnd, FAR const struct nxgl_rect_s *rect,
+ FAR const struct nxgl_point_s *offset);
+
+/****************************************************************************
+ * Name: nxtk_bitmapwindow
+ *
+ * Description:
+ * Copy a rectangular region of a larger image into the rectangle in the
+ * specified client sub-window.
+ *
+ * Input Parameters:
+ * hfwnd The client sub0window that will receive the bitmap image
+ * dest - Describes the rectangular region on in the client sub-window
+ * will receive the bit map.
+ * src - The start of the source image.
+ * origin - The origin of the upper, left-most corner of the full bitmap.
+ * Both dest and origin are in window coordinates, however, origin
+ * may lie outside of the display.
+ * stride - The width of the full source image in pixels.
+ *
+ * Return:
+ * OK on success; ERROR on failure with errno set appropriately
+ *
+ ****************************************************************************/
+
+EXTERN int nxtk_bitmapwindow(NXTKWINDOW hfwnd,
+ FAR const struct nxgl_rect_s *dest,
+ FAR const void *src[CONFIG_NX_NPLANES],
+ FAR const struct nxgl_point_s *origin,
+ unsigned int stride);
+
+/****************************************************************************
* Name: nxtk_opentoolbar
*
* Description:
* Create a tool bar at the top of the specified framed window
*
* Input Parameters:
* hwnd - The handle returned by nxtk_openwindow
* height - The request height of the toolbar in pixels
* cb - Callbacks used to process toolbar events
* arg - User provided value that will be returned with toolbar callbacks.
@@ -208,7 +295,7 @@ EXTERN int nxtk_fillwindow(NXTKWINDOW hfwnd, FAR const struct nxgl_rect_s *rect,
*
****************************************************************************/
-EXTERN NXTKTOOLBAR nxtk_opentoolbar(NXTKWINDOW hwnd, nxgl_coord_t height,
+EXTERN NXTKTOOLBAR nxtk_opentoolbar(NXTKWINDOW hfwnd, nxgl_coord_t height,
FAR const struct nx_callback_s *cb,
FAR void *arg);
@@ -246,6 +333,25 @@ EXTERN void nxtk_closetoolbar(NXTKTOOLBAR htb);
EXTERN int nxtk_filltoolbar(NXTKTOOLBAR htb, FAR const struct nxgl_rect_s *rect,
nxgl_mxpixel_t color[CONFIG_NX_NPLANES]);
+
+/****************************************************************************
+ * Name: nxtk_filltraptoolbar
+ *
+ * Description:
+ * Fill the specified rectangle in the toolbar with the specified color
+ *
+ * Input Parameters:
+ * htb - The window handle returned by nxtk_openwindow
+ * trap - The trapezoidal region to be filled
+ * color - The color to use in the fill
+ *
+ * Return:
+ * OK on success; ERROR on failure with errno set appropriately
+ *
+ ****************************************************************************/
+
+EXTERN int nxtk_filltraptoolbar(NXTKTOOLBAR htb, FAR const struct nxgl_trapezoid_s *trap,
+ nxgl_mxpixel_t color[CONFIG_NX_NPLANES]);
#undef EXTERN
#if defined(__cplusplus)
}
@@ -191,13 +209,82 @@ EXTERN int nxtk_fillwindow(NXTKWINDOW hfwnd, FAR const struct nxgl_rect_s *rect,
*
* Input Parameters:
- * hwnd - The handle returned by nxtk_openwindow
+ * hfwnd - The handle returned by nxtk_openwindow
* height - The request height of the toolbar in pixels
* cb - Callbacks used to process toolbar events